@@ -14,7 +14,7 @@ use File::Basename ();
 use File::Path ();
 
 # ABSTRACT: Test an imaginary beowulf cluster of Clustericious services
-our $VERSION = '0.32'; # VERSION
+our $VERSION = '0.33'; # VERSION
 
 
 BEGIN { $ENV{MOJO_LOG_LEVEL} = 'fatal' }
@@ -309,6 +309,8 @@ sub create_cluster_ok
     {
       $app_name = $item;
     }
+    my $psgi_name = $app_name =~ /\.psgi$/ ? $app_name : "$app_name.psgi";
+
     
     my $app;
     # we want to try to load class first, so that YourApp.pm
@@ -345,15 +347,15 @@ sub create_cluster_ok
         { push @errors, [ $app_name, $error ] }
       }
       
-      if(my $script = Mojo::Loader::data_section($caller, "script/$app_name.psgi"))
+      if(my $script = Mojo::Loader::data_section($caller, "script/$psgi_name"))
       {
         my $home = File::HomeDir->my_home;
         require Mojolicious;
         require Mojolicious::Plugin::MountPSGI;
         $app = Mojolicious->new;
         # TODO: check syntax of .psgi file?
-        $self->extract_data_section("script/$app_name.psgi", $caller);
-        $app->plugin('Mojolicious::Plugin::MountPSGI' => { '/' => "$home/script/$app_name.psgi" });
+        $self->extract_data_section("script/$psgi_name", $caller);
+        $app->plugin('Mojolicious::Plugin::MountPSGI' => { '/' => "$home/script/$psgi_name" });
       }
     }
     
@@ -361,8 +363,8 @@ sub create_cluster_ok
     {
       foreach my $dir (@{ $self->{lite_path} })
       {
-        if(($^O eq 'MSWin32' && -e "$dir/$app_name")
-        || (-x "$dir/$app_name"))
+        if($app_name !~ /\.psgi$/
+        && (($^O eq 'MSWin32' && -e "$dir/$app_name") || (-x "$dir/$app_name")))
         {
           $app = _load_lite_app("$dir/$app_name");
           if(my $error = $@)
@@ -370,12 +372,12 @@ sub create_cluster_ok
           last;
         }
         
-        if(-e "$dir/$app_name.psgi")
+        if(-e "$dir/$psgi_name")
         {
           require Mojolicious;
           require Mojolicious::Plugin::MountPSGI;
           $app = Mojolicious->new;
-          $app->plugin('Mojolicious::Plugin::MountPSGI' => { '/' => "$dir/$app_name.psgi" });
+          $app->plugin('Mojolicious::Plugin::MountPSGI' => { '/' => "$dir/$psgi_name" });
         }
       }
     }
@@ -685,7 +687,7 @@ Test::Clustericious::Cluster - Test an imaginary beowulf cluster of Clustericiou
 
 =head1 VERSION
 
-version 0.32
+version 0.33
 
 =head1 SYNOPSIS
 
